####################################
#### preparation of the data #######
####################################

library(ggplot2)
library(plyr)

#############################
########Load data ###########
#############################
raw_data <- read.csv("exp2_raw_data.csv",sep=";")

#########################
### exclude outliers ####
#########################

# exclude participants giving 0 or 1 correct answer
exclude <- xtabs(Correct ~ ID + Congruency, raw_data) #all ID with less correct answer than 2 in one condition
agg_data <- aggregate.data.frame(subset(raw_data,select=c(Congruency,ID,Correct)),
  list(raw_data$Congruency,raw_data$ID),FUN=mean)#accuracy scores of the participants in the conditions 
ggplot(agg_data, aes(Correct))  + 
  geom_histogram(aes(y = ..density..), colour = "black", fill = "white", bins = 25) + 
  labs(x = "Accuracy", y = "Density")
outlier <- subset(agg_data, agg_data$Correct<(2/27)) # outlier = 0 or 1 correct in one of the conditions
raw_data <- subset(raw_data, !ID %in% outlier$ID)  #excluding outliers
table(table(raw_data$ID)) # #N = 133, 10 participants were excluded

#exclude participants with IQ <= 85
raw_data$ID <- as.numeric(factor(raw_data$Neptun))
raw_data <- raw_data[,-1]
raw_data <- subset(raw_data, IQ > 85)
length(unique(raw_data$ID)) #N = 129, 4 participants excluded

# exclude trials where participants did not meet the 3 seconds time-limit
table(raw_data$Missed)
percentage_of_missed_trials= table(raw_data$Missed)[2]/(table(raw_data$Missed)[1]+table(raw_data$Missed)[2])
percentage_of_missed_trials
raw_data <- subset(raw_data,Missed==0)


########################
#### Classification ####
########################

#### Install current development version of mousetrap from GitHub
#### (needed as long as extension functions are not included in CRAN version)
# devtools::install_github("pascalkieslich/mousetrap@master")

#### Load mousetrap
library(mousetrap)

# Import and process trajectory data
mt_data <- mt_import_mousetrap(raw_data)
mt_data <- mt_remap_symmetric(mt_data)
mt_data <- mt_time_normalize(mt_data)

# Calculate trial indices
mt_data <- mt_measures(mt_data)
hist(mt_data$measures$MD_above,breaks=30) #bimodal distribution of MD

# Convert MAD threshold of Freeman (2014) into percentages
# --> 54 % of maximum possible MAD leads to 0.9 MAD threshold
mt_mad_threshold(start=c(0,0),end=c(-1,1.5),threshold = 0.5408327)

# Translates to MAD threshold of500.5 for current setup
# based on percentage threshold from Freeman
# and using the button mid points of the current study
mt_mad_threshold(start=c(0,-353), end=c(-612,354), threshold = 0.5408327)

# Get corresponding AOIs
mad_aois <- mt_mad_threshold(mt_data, return_aoi = TRUE, start=c(0,-353), end=c(-612,354), threshold = 0.5408327)

# Classify points into AOIs
mt_data <- mt_classify(mt_data,aoi = mad_aois)

# Visualize classification and AOIs (commented out as it takes some time)
# with(mt_data,plot(trajectories[,,"xpos"],trajectories[,,"ypos"],col=trajectories[,,"classification"]+1))
# lines(mad_aois[[1]],col="blue")
# lines(mad_aois[[2]],col="blue")

# Summarize classifications
mt_data <- mt_summarize(mt_data,classification = "classification", save_as="sum_trajectories")

# Remove 0 classifications (all periods outside button AOIs) and duplicates
mt_data <- mt_remove(mt_data, use="sum_trajectories", remove=0, exclude_duplicate_categories = TRUE)

# Summarize classifications
mt_data <- mt_concatenate(mt_data,use="sum_trajectories",coding=c(L=1,R=2), label="CoM_pattern")


### Descriptives of the classification analysis

# Classification without duplicates
table(mt_data$measures$CoM_pattern)

# Count number of commitments
mt_data$measures$ncommitments <- mt_count(mt_data$sum_trajectories)
table(mt_data$measures$ncommitments)


####################################################
#Create and merge dataframes with data relevant data
####################################################

## Create new data.frame that only contains first classified movement (excluding 0 classifications)
first_classification <- data.frame(mt_data$sum_trajectories[,1,])
first_classification$mt_id <- row.names(first_classification) # add mt_id variable
first_classification$RT_first <- first_classification$timestamps

# merge by mt_id variable
data_allvariables <- merge(mt_data$data,first_classification, by = "mt_id")
data_allvariables <- merge(data_allvariables,mt_data$measures, by = "mt_id")

## rename columns of interest
data_allvariables <- rename(data_allvariables, c("Type_name" = "Congruency_f","classification"="CoM", "RT.x" = "RT", "composit"="composite"))

#subset the columns of interest
data <- data_allvariables[,c("ID", "mt_id", "RT", "gender","age","Congruency",
                             "Congruency_f","Correct","Missed", "CoM", "CoM_pattern",
                             "ncommitments","IQ","IQ_z","numeracy","numeracy_setting", "numeracy_z", "composite","MD_above")]


################################
###Preparation of some variables
################################
data$age <- as.numeric(as.character(data$age))
data$age <- 2016 - data$age
data$nchanges <- data$ncommitments - 1 #calculate number of changes
data$CoM <- ifelse(data$CoM == 2, 1,0) #base CoM classification on classification of first commitment
# (if it was to the right (==2), one CoM occurred - if it was to the left (==1), there was no CoM)

#calculate Correctfirst
data$Correctfirst <- ifelse(data$Correct == 1,
                            ifelse(data$CoM == 0,1,0),
                            ifelse(data$CoM == 1,1,0))

#create factor variables
data$Correctfirst_f <- ordered(data$Correctfirst, levels = c(0,1), labels = c("Incorrect", "Correct"))
data$Correct_f <- ordered(data$Correct, levels = c(0,1), labels = c("Incorrect", "Correct"))
data$CoM_f <- ordered(data$CoM, levels = c(0,1), labels = c("NoCoM", "CoM"))
data$IQ_d <- as.factor(ifelse(data$IQ <= median(data$IQ), "low_IQ","high_IQ"))
data$numeracy_d <- as.factor(ifelse(data$numeracy <= median(data$numeracy), "low_num","high_num"))
data$composite <- round(data$composite,digits=7)
data$composite_d <- as.factor(ifelse(data$composite <= median(data$composite), "low_cog","high_cog"))
data$gender <- revalue(data$gender, c("F\xe9rfi"="Male", "N\xf5"="Female"))

##### Export data
write.table(data, "exp2_data.csv", sep=";")